package com.juling.ipage.navigation

import android.content.Context
import android.graphics.drawable.Drawable
import android.util.AttributeSet
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.TextView
import com.juling.ipage.R
import com.work.provide_tool.util.getResDraw
import com.work.provide_tool.util.getResStringArray
import com.work.provide_tool.util.getResTone

class NavigationView : LinearLayout {
    private lateinit var navigationLl:LinearLayout
    private val navigationHolderArray  = ArrayList<NavigationViewHolder>()
    private val initTotal = 3 //init 个数
    private val initWordArray by lazy {
        getResStringArray(R.array.navigation_init_word_with_array)
    }
    private val initDrawArrayWithNor =
        arrayOf(getResDraw(R.mipmap.navigation_info_nor)
            , getResDraw(R.mipmap.navigation_friend_nor)
            , getResDraw(R.mipmap.navigation_uinfo_nor)
        )

    private val initDrawArrayWithIn =
        arrayOf(getResDraw(R.mipmap.navigation_info_sel)
            , getResDraw(R.mipmap.navigation_friend_sel)
            , getResDraw(R.mipmap.navigation_uinfo_sel)
        )

    private var needTotal:Int = initTotal
    private lateinit var wordArray:Array<String>
    private lateinit var drawArrayNor:Array<Drawable?>
    private lateinit var drawArrayIn:Array<Drawable?>

    private var iPos = -1//当前的位置

    var navigationWidgetClick:NavigationWidgetClick? = null

    data class NavigationViewHolder(var ll:LinearLayout,var tv:TextView,var iv:ImageView)

    constructor(context: Context) : super(context) {
        init(context)
    }

    constructor(context: Context, attrs: AttributeSet?) : super(context, attrs) {
        init(context)
    }

    constructor(context: Context, attrs: AttributeSet?, defStyleAttr: Int) : super(
        context,
        attrs,
        defStyleAttr
    ) {
        init(context)
    }

    private fun init(context: Context) {
        LayoutInflater.from(context).inflate(R.layout.navigation_linearlayout,this)
        navigationLl = findViewById(R.id.navigation_view_ll)

        loadNavigation()
    }

//    增加单元view(widget)
//    Init  widget数据：图片、文字
//    位置： 刷widget
    fun loadNavigation(
    initTotal:Int = this.initTotal,
    initWordArray: Array<String> = this.initWordArray,
    initDrawArrayWithNor: Array<Drawable?> = this.initDrawArrayWithNor,
    initDrawArrayWithIn: Array<Drawable?> = this.initDrawArrayWithIn,
    ) {
        updateNavigationData(initTotal,initWordArray,initDrawArrayWithNor,initDrawArrayWithIn)
        addNavigationWidget(initTotal)
        loadAllWord(initWordArray)
        loadAllDraw(initDrawArrayWithNor)
        setPos(iPos,0)
    }

    private fun updateNavigationData(initTotal:Int,
                                     initWordArray: Array<String>,
                                     initDrawArrayWithNor: Array<Drawable?>,
                                     initDrawArrayWithIn: Array<Drawable?>,){
        needTotal = initTotal
        wordArray = initWordArray
        drawArrayNor = initDrawArrayWithNor
        drawArrayIn = initDrawArrayWithIn
    }

    private fun addNavigationWidget(initTotal: Int) {
        navigationLl.removeAllViews()
        navigationHolderArray.clear()
        for (i in 0 until initTotal){
            provideWidgetView().apply {
                navigationLl.addView(this)

                navigationHolderArray.add(
                    NavigationViewHolder(
                        findViewById(R.id.widget_linearlayout),
                        findViewById(R.id.tv),
                        findViewById(R.id.iv)
                    )
                )

                findViewById<LinearLayout>(R.id.widget_linearlayout).setOnClickListener {
                    setPos(iPos,i)
                }
            }
        }
    }

    private fun provideWidgetView():View{
        return  LayoutInflater.from(context).inflate(R.layout.navigation_linearlayout_widget,null).apply {
            var lp = LinearLayout.LayoutParams(0,LinearLayout.LayoutParams.MATCH_PARENT)
            lp.weight = 1f
            layoutParams = lp
        }
    }

    //---------------------------------------------------文案---------------------------------------------------
    fun loadAllWord(wordArray:Array<String>?){
        wordArray?.run {
            check(wordArray.size == navigationHolderArray.size){
                "NavigationView > updateAllWord word length ("+wordArray.size+") != tv length("+navigationHolderArray.size+")"
            }

            for (i in wordArray.indices){
                loadWordPos(wordArray[i],i)
            }
        }
    }

    fun loadWordPos(word:String?,pos:Int){
        word?.run {
            check(pos in 0 until navigationHolderArray.size){
                "NavigationView > updateWordPos  pos = $pos out length("+navigationHolderArray.size+")"
            }
            navigationHolderArray[pos].tv.text = word
        }
    }
    //---------------------------------------------------/文案---------------------------------------------------

    //---------------------------------------------------图片---------------------------------------------------
    fun loadAllDraw(drawArray:Array<Drawable?>?){
        drawArray?.run {
            check(drawArray.size == navigationHolderArray.size){
                "NavigationView > updateAllDraw draw length("+drawArray.size+") != iv length("+navigationHolderArray.size+")"
            }
            for (i in drawArray.indices){
                loadDrawPos(drawArray[i],i)
            }
        }
    }

    fun loadDrawPos(draw:Drawable?,pos:Int){
        draw?.run {
            check(pos in 0 until navigationHolderArray.size){
                "NavigationView > updateDrawPos  pos($pos) out length("+navigationHolderArray.size+")"
            }
            navigationHolderArray[pos].iv.background = draw
        }
    }
    //---------------------------------------------------/图片---------------------------------------------------

    //---------------------------------------------------位置---------------------------------------------------
    fun setPos(f:Int,to:Int){
        navigationWidgetClick?.onClick(f,to)
        if(f != to){
            updateWordPos(f,to)
            updateDrawPos(f,to)
            iPos = to
        }
    }

    fun updateWordPos(f:Int,to:Int){
        check(to in 0 until navigationHolderArray.size){
            "NavigationView > updateWordPos pos($to) out length("+navigationHolderArray.size+")"
        }
        if(f != -1){
            navigationHolderArray[f].tv.setTextColor(getResTone(R.color.navigation_nor_tv_with_draw))
        }
        navigationHolderArray[to].tv.setTextColor(getResTone(R.color.navigation_sel_tv_with_draw))
    }

    fun updateDrawPos(f:Int,to:Int){
        check(to in 0 until navigationHolderArray.size){
            "NavigationView > updateDrawPos pos($to) out length("+navigationHolderArray.size+")"
        }
        if(f != -1){
            navigationHolderArray[f].iv.background = drawArrayNor[f]
        }
        navigationHolderArray[to].iv.background = drawArrayIn[to]
    }
    //---------------------------------------------------/位置---------------------------------------------------

    //网络数据（导航栏）
    fun updateNetNavigation(){
//        loadNavigation() //1
    }









}